=========
RofiPaste
=========


.. image:: https://img.shields.io/pypi/v/rofipaste.svg
        :target: https://pypi.python.org/pypi/rofipaste

.. image:: https://img.shields.io/travis/com/Any0ne22/rofipaste.svg
        :target: https://travis-ci.com/github/Any0ne22/rofipaste

.. image:: https://readthedocs.org/projects/rofipaste/badge/?version=latest
        :target: https://rofipaste.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/Any0ne22/rofipaste/shield.svg
     :target: https://pyup.io/repos/github/Any0ne22/rofipaste/
     :alt: Updates



A tool to paste some useful things using rofi (rofi needs to be installed to use this package)


* Free software: GNU General Public License v3
* Documentation: https://rofipaste.readthedocs.io.

Features
--------

- You can paste all the entries you have created

- You can create new entries

- You can create executable entries


* TODO

  - Edit CONTRIBUTING.rst if necessary

  - Edit HISTORY.rst if necessary
  
  - Create requirements.txt (and use it instead of requirements_dev.txt for the installation)
  
  - Create tests
  
  - Write documentation


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

This package was inspired and developed from the rofimoji_ project.

.. _rofimoji: https://github.com/fdw/rofimoji
